import DataTable, {Api} from "datatables.net-bs5";
// @ts-expect-error
import Autocomplete from "bootstrap5-autocomplete";
import {getCurrentlySelectedList} from "./userlists";

const SEARCH_API_URL = '/api/web/share/search';
const ADD_API_URL = '/api/web/share/add';
const REMOVE_API_URL = '/api/web/share/remove';

const DT_API_URL = '/api/dt/list/users';

let dtApi: Api;

function actionColumnRender(
    id: number, type: string
) {
    if (type !== 'display') {
        return id;
    }
    
    const icon = document.createElement('i');
    icon.classList.add('fa-solid', 'fa-xmark', 'text-danger', 'cursor-pointer', 'fa-xl');
    icon.addEventListener('click', async () => {
        const formData = new FormData();
        formData.append('requestedUser', id.toString() ?? '');
        formData.append('listid', getCurrentlySelectedList()?.toString() ?? '');

        const response = await fetch(
            REMOVE_API_URL,
            {
                method: 'POST',
                body: formData
            }
        );

        if (!response.ok) {
            throw new Error(response.statusText);
        }
        
        dtApi.ajax.reload();
    })
    
    return icon;
}

export function initShare() {
    const input = document.querySelector<HTMLInputElement>('#share-user-search');
    if (!input) {
        throw new Error("Missing search element");
    }
    let currentlySelected: number|null = null;
    const autocomplete = new Autocomplete(input, {
        server: SEARCH_API_URL,
        liveServer: true,
        fullWidth: true,
        fixed: true,
        
        onSelectItem(item: Object, instance: Autocomplete) {
            // @ts-expect-error
            currentlySelected = item.value;
        }
    })
    
    document.querySelector<HTMLButtonElement>('.js--adds-user')?.addEventListener('click', async (e) => {
        const formData = new FormData();
        formData.append('requested', currentlySelected?.toString() ?? '');
        formData.append('listid', getCurrentlySelectedList()?.toString() ?? '');
        
        const response = await fetch(
            ADD_API_URL, 
            {
                method: 'POST',
                body: formData
            }
        );
        
        if (!response.ok) {
            throw new Error(response.statusText);
        }
        
        dtApi.ajax.reload()
    })
    
    const table = document.querySelector<HTMLTableElement>('#shared-users-table');
    if (!table) {
        return;
    }

    dtApi = new DataTable(table, {
        columns: [
            {
                name: '',
                title: 'Icon',
                data: 'icon',
                className: 'avatar',
                searchable: false,
                orderable: false,
                width: 'auto',
                render(data, type) {
                    if (type !== 'display') {
                        return data;
                    }
                    
                    return `<img src="${ data }" alt="Profile Picture" class="avatar-icon h-100 position-relative me-2 ratio-1 rounded-circle" />`;
                }
            },
            {
                name: 'Name',
                data: 'name',
                title: 'Name'
            },
            {
                name: 'actions',
                data: 'id',
                render: actionColumnRender,
                searchable: false,
                orderable: false,
                type: 'html'
            }
        ],
        ajax: {
            url: DT_API_URL,
            data(data) {
                // @ts-expect-error
                data.listid = getCurrentlySelectedList()
            }
        },
        order: [ [1, "desc"] ]
    });
}