<?php

namespace GamesShop\Routing\Api\Web;

use Doctrine\ORM\EntityManager;
use GamesShop\Entities\Account\User;
use GamesShop\Entities\GamesList;
use GamesShop\Login\LoginHandler;
use GamesShop\Login\UserPermission;
use Laminas\Diactoros\Response;
use League\Route\Http\Exception\BadRequestException;
use League\Route\Http\Exception\ForbiddenException;
use League\Route\Http\Exception\UnauthorizedException;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;

class AddUserToList
{

    public function __construct(
        private readonly LoginHandler $loginHandler,
        private readonly EntityManager $entityManager,
    )
    {
    }

    public function __invoke(ServerRequestInterface $request): ResponseInterface
    {
        if (!$this->loginHandler->isLoggedIn()) {
            throw new UnauthorizedException();
        }

        $user = $this->loginHandler->getCurrentUser();
        if (!$user->getPermission()->hasLevel(UserPermission::PROVIDER)) {
            throw new ForbiddenException();
        }
        
        $body = $request->getParsedBody();
        if (!array_key_exists('listid', $body)) {
            throw new BadRequestException();
        }

        $list = $this->entityManager->getRepository(GamesList::class)->findOneBy([ 'owner' => $user, 'id' => $body['listid'] ]);
        if (!$list instanceof GamesList) {
            throw new BadRequestException();
        }
        
        
        $requestedUser = $this->entityManager->getRepository(User::class)
            ->find($body['requested']);
        
        if ($list->getClaimer()->contains($requestedUser)) {
            return new Response();
        }
        $list->addClaimer($requestedUser);
        
        $this->entityManager->flush();
        
        return new Response();
    }
}