<?php
declare(strict_types=1);

namespace GamesShop\Routing\Api\Web;

use Doctrine\ORM\EntityManager;
use GamesShop\Entities\GamesList;
use GamesShop\Login\LoginHandler;
use GamesShop\Login\UserPermission;
use Laminas\Diactoros\Response;
use League\Route\Http\Exception\BadRequestException;
use League\Route\Http\Exception\ForbiddenException;
use League\Route\Http\Exception\UnauthorizedException;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;

final class CreateKeyListRoute
{
    public function __construct(
        private readonly LoginHandler $loginHandler,
        private readonly EntityManager $entityManager
    )
    {
    }

    public function __invoke(ServerRequestInterface $request): ResponseInterface
    {
        if (!$this->loginHandler->isLoggedIn()) {
            throw new UnauthorizedException();
        }

        $user = $this->loginHandler->getCurrentUser();
        if (!$user->getPermission()->hasLevel(UserPermission::PROVIDER)) {
            throw new ForbiddenException();
        }

        $body = $request->getParsedBody();
        if (!array_key_exists('name', $body)) {
            throw new BadRequestException();
        }

        $name = $body['name'];
        $list = new GamesList($user, $name);
        $this->entityManager->persist($list);
        $this->entityManager->flush();

        return new Response();
    }
}